package
    Test::YA::CLI::Example;
use Moo;

extends 'YA::CLI';


__PACKAGE__->meta->make_immutable;
